#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import numpy
from datetime import datetime

from lsl.common.stations import lwa1

from matplotlib import pyplot as plt


def parseFile(filename):
	obs = lwa1.getObserver()
	fh = open(filename, 'r')
	
	# Get the date
	line = fh.readline()
	fields = line.split()
	date = fields[1]

	# Get the data
	tuning1 = {}
	tuning2 = {}
	for line in fh:
		line = line.replace('\n', '')
		fields = line.split()
		if len(fields) != 15:
			continue
			
		time = fields[0]
		obs.date = '%s %s' % (date, time)
		lst = obs.sidereal_time()*12/numpy.pi
		
		gain1  = int(fields[2])
		gain2  = int(fields[3])
		
		clip1 = max([float(fields[5][:-1]), float(fields[6][:-1])])
		clip2 = max([float(fields[7][:-1]), float(fields[8][:-1])])
		power1 = 0.5*(float(fields[10]) + float(fields[11]))
		power2 = 0.5*(float(fields[12]) + float(fields[13]))
		
		try:
			tuning1[gain1][  'lst'].append( lst )
			tuning1[gain1][ 'clip'].append( clip1 )
			tuning1[gain1]['power'].append( power1 )
			tuning2[gain2][  'lst'].append( lst )
			tuning2[gain2][ 'clip'].append( clip2 )
			tuning2[gain2]['power'].append( power2 )
		except KeyError:
			tuning1[gain1] = {}
			tuning1[gain1][  'lst'] = [lst,]
			tuning1[gain1][ 'clip'] = [clip1,]
			tuning1[gain1]['power'] = [power1,]
			tuning2[gain2] = {}
			tuning2[gain2][  'lst'] = [lst,]
			tuning2[gain2][ 'clip'] = [clip2,]
			tuning2[gain2]['power'] = [power2,]
	fh.close()
	
	for tuning in (tuning1, tuning2):
		for g in tuning.keys():
			tuning[g]['lst'] = tuning[g]['lst'][0]
			for k in ('clip', 'power'):
				tuning[g][k] = numpy.median( numpy.array(tuning[g][k]) )
				
	return tuning1, tuning2


def main(args):
	gainToUse = int(args[0])
	filenames = args[1:]
	
	output = []
	for filename in filenames:
		output.append( [] )
		try:
			data1, data2 = parseFile(filename)
		
			for i,data in zip((1, 2), (data1, data2)):
				best = None
				bestPower = 0
				for g in sorted(data.keys()):
					#print filename, g, data[g]['clip']
					if g == gainToUse:
						best = g
						bestPower = data[g]['power']
						
				output[-1].append( best )
				output[-1].append( data[best][ 'lst'] )
				output[-1].append( data[best][ 'clip'] )
				output[-1].append( data[best]['power'] )
				
		except Exception, e:
			print "ERROR: %s on %s" % (str(e), filename)
			continue
			
	output = numpy.array(output)
	
	fig = plt.figure()
	
	ax1 = fig.add_subplot(2, 1, 1)
	ax1.plot(output[:,1], output[:,0], linestyle=' ', marker='x', label='Tuning 1')
	ax1.plot(output[:,5], output[:,4], linestyle=' ', marker='+', label='Tuning 2')
	ax1.set_xlabel('LST [hr]')
	ax1.set_ylabel('DRX Gain')
	ax1.legend(loc=0)
	ax1.set_xlim((0,24))
	ax1.set_ylim((3, 9))
	
	ax2 = fig.add_subplot(2, 2, 3)
	ax2.plot(output[:,1], output[:,2], linestyle=' ', marker='x', label='Tuning 1')
	ax2.plot(output[:,5], output[:,6], linestyle=' ', marker='+', label='Tuning 2')
	ax2.set_xlabel('LST [hr]')
	ax2.set_ylabel('Clipping [%]')
	ax2.set_xlim((0,24))
	
	ax3 = fig.add_subplot(2, 2, 4)
	ax3.plot(output[:,1], output[:,3], linestyle=' ', marker='x', label='Tuning 1')
	ax3.plot(output[:,5], output[:,7], linestyle=' ', marker='+', label='Tuning 2')
	ax3.set_xlabel('LST [hr]')
	ax3.set_ylabel('Power [arb.]')
	ax3.set_xlim((0,24))
	
	plt.show()


if __name__ == "__main__":
	main(sys.argv[1:])

